@@ -18,7 +18,7 @@
 from fabric.api import local as local_cmd  # import local with alternate name
 from instanceinfo import InstanceInfo
 import distutils.sysconfig
-from git import Repo
+#from git import Repo
 import sys
 import os
 from time import gmtime, strftime
@@ -535,7 +535,7 @@ def remote_inflate_code(numKeep='5'):
 
 @task
 def codeversioner():
-    repo = Repo('.')
+#    repo = Repo('.')
     headcommit = repo.head.commit
     commitid = headcommit.hexsha
     versionhash = commitid
